==> node-radius-server-v1.0.0.zip: node-radius-server-v1.0.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

## 1.0.0 (2020-02-27)


### Features

* **ssl:** enable session resumptions for even quicker reintinaliztions :) ([e1b4bb5](https://github.com/simllll/node-radius-server/commit/e1b4bb5597ac74f10b120a5f8cfef7b407a48c8f))
* add debug pkg to reduce output ([9fe25a8](https://github.com/simllll/node-radius-server/commit/9fe25a8b497071ea9276785b7f7710ae0e1e88f8))
* add more auth providers and cleanup google auth ([3f600c6](https://github.com/simllll/node-radius-server/commit/3f600c664ffa7315053d47773c7f9d5060b68d32))
* inner tunnel for TTSL support added ([6aa4b9f](https://github.com/simllll/node-radius-server/commit/6aa4b9f92efb271ee327d3d70bccba27284304ee))


### Bug Fixes

* **docs:** better file names ([5897498](https://github.com/simllll/node-radius-server/commit/589749883c4c881c3af753530987d6f57d8d809d))
* improve coping with long running auth requests ([7ca60a2](https://github.com/simllll/node-radius-server/commit/7ca60a20cc24eb8100ed1f20fe18e7ec664fd176))
* **auth:** improve google auth ([0baf815](https://github.com/simllll/node-radius-server/commit/0baf8155bf74fed9e08826b1aea8242f72c81878))
* **docs:** add examples ([a3ed0be](https://github.com/simllll/node-radius-server/commit/a3ed0be02db0a7fcd89544c89d9b0ee11e949808))
* docs ([cca4dce](https://github.com/simllll/node-radius-server/commit/cca4dce96142d2b2d04b419bd7500e3841262235))
* ldap auth failed auth and added test scripts ([5e5005c](https://github.com/simllll/node-radius-server/commit/5e5005cf6bcbc3d9450db3651478249f8deb92a6))
* ssl again ([a624bc1](https://github.com/simllll/node-radius-server/commit/a624bc15b0e1fde4f2a268c62500b090e4f366a5))
* **ssl:** move files ([f53a423](https://github.com/simllll/node-radius-server/commit/f53a42335bb583af7575b8cf5fcf5fe58cdeaed4))
* a lot of bug fixes, first running version for windows and android :) ([0cb807a](https://github.com/simllll/node-radius-server/commit/0cb807a555febec461edf1280fe1a7e1b72186b0))
* a lot of bug fixes, first running version for windows and android :) ([4989c2b](https://github.com/simllll/node-radius-server/commit/4989c2b6bc162a1688e84c21919835cb8637854c))
* add MS-MPPE-Send-Key and MS-MPPE-Recv-Key ([7e28c60](https://github.com/simllll/node-radius-server/commit/7e28c60d81abe4c2c5269babbf6ef5951d65d682))
* eap call is using wrong this, needs more refactoring later ([837453f](https://github.com/simllll/node-radius-server/commit/837453fca250abb45f1069405b96e29fc0e3e9c4))

# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

==> node-radius-server-v1.1.2.zip: node-radius-server-v1.1.2/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [1.1.2](https://github.com/simllll/node-radius-server/compare/v1.1.1...v1.1.2) (2020-03-02)

### [1.1.1](https://github.com/simllll/node-radius-server/compare/v1.1.0...v1.1.1) (2020-03-02)


### Bug Fixes

* **auth:** cache only valid results for one day ([a8a0247](https://github.com/simllll/node-radius-server/commit/a8a02478ce522eb51c46517b4176aa0d50481676))
* **config:** use __dirname to resolve path to ssl certs ([7a28a0d](https://github.com/simllll/node-radius-server/commit/7a28a0dc6bfbae307765e03f4b15c57c84fa0dc2))
* **docs:** fix some typos ([5519391](https://github.com/simllll/node-radius-server/commit/5519391aa3c688422da8d98a3bd789615738b974))

## [1.1.0](https://github.com/simllll/node-radius-server/compare/v1.0.0...v1.1.0) (2020-02-28)


### Features

* **cli:** allow setting config vars via cli ([d9ff95b](https://github.com/simllll/node-radius-server/commit/d9ff95bbbbea9ade9721e3f5d4dc2323988da3d6))

## 1.0.0 (2020-02-27)


### Features

* **ssl:** enable session resumptions for even quicker reintinaliztions :) ([e1b4bb5](https://github.com/simllll/node-radius-server/commit/e1b4bb5597ac74f10b120a5f8cfef7b407a48c8f))
* add debug pkg to reduce output ([9fe25a8](https://github.com/simllll/node-radius-server/commit/9fe25a8b497071ea9276785b7f7710ae0e1e88f8))
* add more auth providers and cleanup google auth ([3f600c6](https://github.com/simllll/node-radius-server/commit/3f600c664ffa7315053d47773c7f9d5060b68d32))
* inner tunnel for TTSL support added ([6aa4b9f](https://github.com/simllll/node-radius-server/commit/6aa4b9f92efb271ee327d3d70bccba27284304ee))


### Bug Fixes

* **docs:** better file names ([5897498](https://github.com/simllll/node-radius-server/commit/589749883c4c881c3af753530987d6f57d8d809d))
* improve coping with long running auth requests ([7ca60a2](https://github.com/simllll/node-radius-server/commit/7ca60a20cc24eb8100ed1f20fe18e7ec664fd176))
* **auth:** improve google auth ([0baf815](https://github.com/simllll/node-radius-server/commit/0baf8155bf74fed9e08826b1aea8242f72c81878))
* **docs:** add examples ([a3ed0be](https://github.com/simllll/node-radius-server/commit/a3ed0be02db0a7fcd89544c89d9b0ee11e949808))
* docs ([cca4dce](https://github.com/simllll/node-radius-server/commit/cca4dce96142d2b2d04b419bd7500e3841262235))
* ldap auth failed auth and added test scripts ([5e5005c](https://github.com/simllll/node-radius-server/commit/5e5005cf6bcbc3d9450db3651478249f8deb92a6))
* ssl again ([a624bc1](https://github.com/simllll/node-radius-server/commit/a624bc15b0e1fde4f2a268c62500b090e4f366a5))
* **ssl:** move files ([f53a423](https://github.com/simllll/node-radius-server/commit/f53a42335bb583af7575b8cf5fcf5fe58cdeaed4))
* a lot of bug fixes, first running version for windows and android :) ([0cb807a](https://github.com/simllll/node-radius-server/commit/0cb807a555febec461edf1280fe1a7e1b72186b0))
* a lot of bug fixes, first running version for windows and android :) ([4989c2b](https://github.com/simllll/node-radius-server/commit/4989c2b6bc162a1688e84c21919835cb8637854c))
* add MS-MPPE-Send-Key and MS-MPPE-Recv-Key ([7e28c60](https://github.com/simllll/node-radius-server/commit/7e28c60d81abe4c2c5269babbf6ef5951d65d682))
* eap call is using wrong this, needs more refactoring later ([837453f](https://github.com/simllll/node-radius-server/commit/837453fca250abb45f1069405b96e29fc0e3e9c4))

# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.
